@@ -729,8 +729,8 @@ class Script(default.Script):
                      pyatspi.ROLE_ROOT_PANE,
                      pyatspi.ROLE_FRAME,
                      pyatspi.ROLE_APPLICATION]
-        if self.utilities.hasMatchingHierarchy(event.source, rolesList):
-            for child in event.source.parent:
+        if self.utilities.hasMatchingHierarchy(newLocusOfFocus, rolesList):
+            for child in newLocusOfFocus.parent:
                 if child.getRole() == pyatspi.ROLE_PAGE_TAB_LIST:
                     for tab in child:
                         eventState = tab.getState()
@@ -942,6 +942,10 @@ class Script(default.Script):
         if event.source.getRoleName() == 'text frame':
             return
 
+        ignoreRoles = [pyatspi.ROLE_FILLER, pyatspi.ROLE_PANEL]
+        if event.source.getRole() in ignoreRoles:
+            return
+
         parent = event.source.parent
         if parent and parent.getRoleName() == 'text frame':
             return
@@ -952,6 +956,9 @@ class Script(default.Script):
         if start != end:
             return
 
+        if self.utilities._flowsFromOrToSelection(event.source):
+            return
+
         # We should present this in response to active-descendant-changed events
         if event.source.getState().contains(pyatspi.STATE_MANAGES_DESCENDANTS):
             return
@@ -997,6 +1004,9 @@ class Script(default.Script):
                [pyatspi.ROLE_FRAME]):
             orca.setLocusOfFocus(event, event.source, False)
 
+        if self.utilities._flowsFromOrToSelection(event.source):
+            return
+
         default.Script.onCaretMoved(self, event)
 
     def onCheckedChanged(self, event):
